@@ -1,6 +1,6 @@
 package swat;
 
-our $VERSION = '0.1.45';
+our $VERSION = '0.1.46';
 
 use base 'Exporter'; 
 
@@ -104,8 +104,8 @@ sub check_line {
 
 sub header {
 
-    diag("start swat for $url/$path | project $project | is swat package $is_swat_package") if debug_mod2();
-    diag("swat version $swat::VERSION | debug $debug | try num $try_num | ignore http errors $ignore_http_err") if debug_mod2();
+    diag("start swat for $url/$path | project $project | is swat package $is_swat_package") if debug_mod1() or debug_mod2();
+    diag("swat version $swat::VERSION | debug $debug | try num $try_num | ignore http errors $ignore_http_err") if debug_mod1() or debug_mod2();
 }
 
 sub generate_asserts {
